@@ -2,6 +2,7 @@ import operator as op
 
 import sqlalchemy.exc
 from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm.scoping import scoped_session
 
 from functions import first, identity, keys, last, merge, rest
 
@@ -21,6 +22,11 @@ def get_session(engine):
     return sessionmaker(bind=engine)()
 
 
+def get_scoped_session(engine):
+    """Return a scoped session to a database"""
+    return scoped_session(sessionmaker(bind=engine))
+
+
 def query(db, sql_and_params, as_arrays=False, identifiers=op.methodcaller('lower'),
           result_set_fn=tuple, row_fn=identity):
     """Perform a database query"""
